@@ -1,6 +1,6 @@
 # last modified 14 April 2001 by J. Fox
 
-residuals.sem <- function(object){
+residuals.sem <- function(object, ...){
     object$S - object$C
     }    
 
@@ -8,7 +8,7 @@ standardized.residuals <- function(object, ...){
     UseMethod("standardized.residuals")
     }
 
-standardized.residuals.sem <- function(object){
+standardized.residuals.sem <- function(object, ...){
     res <- residuals(object)
     s <- diag(object$S)
     res/sqrt(outer(s, s))
@@ -18,7 +18,7 @@ normalized.residuals <- function(object, ...){
     UseMethod("normalized.residuals")
     }
     
-normalized.residuals.sem <- function(object){
+normalized.residuals.sem <- function(object, ...){
     res <- residuals(object)
     N <- object$N
     C <- object$C
